//
// Author: Valerio Bertone: valerio.bertone@cern.ch
//

#ifndef TMDLIB_FACTORIES_H
#define TMDLIB_FACTORIES_H

#include "tmdgrid.h"
#include "structgrid.h"

namespace TMDlib
{
/**
 * @brief Factory that returns a "TMDGrid" object.
 * @param name: name of the TMD set (assumed to be in the current folder for now)
 * @param mem: member to be read (defaul: 0, i.e. central member)
 */
TMDGrid* mkTMD(std::string const& name, int const& mem = 0);

/**
 * @brief Factory that returns a "TMDGrid" object.
 * @param name: name of the TMD set
 * @param name: name of the folder where the TMD set is
 * @param mem: member to be read (defaul: 0, i.e. central member)
 */
TMDGrid* mkTMD(std::string const& name, std::string const& folder, int const& mem = 0);

/**
 * @brief Factory that returns a vector of "TMDGrid" objects.
 * @param name: name of the TMD set (assumed to be in the current folder for now)
 */
std::vector<TMDGrid*> mkTMDs(std::string const& name);

/**
 * @brief Factory that returns a "StructGrid" object.
 * @param name: name of the structure function set (assumed to be in the current folder for now)
 * @param mem: member to be read (defaul: 0, i.e. central member)
 */
StructGrid* mkSF(std::string const& name, int const& mem = 0);

/**
 * @brief Factory that returns a "StructGrid" object.
 * @param name: name of the structure function set
 * @param name: name of the folder where the structure function set is
 * @param mem: member to be read (defaul: 0, i.e. central member)
 */
StructGrid* mkSF(std::string const& name, std::string const& folder, int const& mem = 0);

/**
 * @brief Factory that returns a vector of "StructGrid" objects.
 * @param name: name of the structure function set (assumed to be in the current folder for now)
 */
std::vector<StructGrid*> mkSFs(std::string const& name);
}
#endif
